@@ -1,4 +1,7 @@
-#undef IS_ADDRESS_SPACE_CONSTRAINED
+// Remove parameters feed from test harness
+#undef ADDRESS_SPACE_CONSTRAINED
+#undef REALLY_ADDRESS_SPACE_CONSTRAINED
+
 #define SNMALLOC_NAME_MANGLE(a) host_##a
 #define NO_BOOTSTRAP_ALLOCATOR
 #define SNMALLOC_EXPOSE_PAGEMAP
